@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "rg" "2.4.0"
+(define-package "rg" "20251022.457"
   "A search tool based on ripgrep."
-  '((emacs     "26.1")
+  '((emacs     "28.1")
     (transient "0.9.2")
     (wgrep     "2.1.10"))
   :url "https://github.com/dajva/rg.el"
-  :commit "b123ac91b86f0ec5479934b0569d9e612fe1e2d5"
-  :revdesc "b123ac91b86f"
+  :commit "9ff6cb24bda58f481886ebaf16b524f4f9b3769c"
+  :revdesc "9ff6cb24bda5"
   :keywords '("matching" "tools")
   :authors '(("David Landell" . "david.landell@sunnyhill.email")
              ("Roland McGrath" . "roland@gnu.org"))
